@@ -3,10 +3,12 @@
 import os
 import signal
 import socket
-import sys
 import tempfile
 import unittest
-from mock import Mock, patch, sentinel
+
+from supervisor.tests.base import Mock, patch, sentinel
+from supervisor.compat import maxint
+
 from supervisor import datatypes
 
 class ProcessOrGroupName(unittest.TestCase):
@@ -17,14 +19,18 @@ class ProcessOrGroupName(unittest.TestCase):
         name = " foo\t"
         self.assertEqual(self._callFUT(name), "foo")
 
-    def test_disallows_inner_spaces(self):
+    def test_disallows_inner_spaces_for_eventlister_protocol(self):
         name = "foo bar"
         self.assertRaises(ValueError, self._callFUT, name)
 
-    def test_disallows_colons(self):
+    def test_disallows_colons_for_eventlistener_protocol(self):
         name = "foo:bar"
         self.assertRaises(ValueError, self._callFUT, name)
 
+    def test_disallows_slashes_for_web_ui_urls(self):
+        name = "foo/bar"
+        self.assertRaises(ValueError, self._callFUT, name)
+
 class IntegerTests(unittest.TestCase):
     def _callFUT(self, arg):
         return datatypes.integer(arg)
@@ -33,7 +39,7 @@ class IntegerTests(unittest.TestCase):
         self.assertEqual(self._callFUT('1'), 1)
 
     def test_converts_numeric_overflowing_int(self):
-        self.assertEqual(self._callFUT(str(sys.maxint+1)), sys.maxint+1)
+        self.assertEqual(self._callFUT(str(maxint+1)), maxint+1)
 
     def test_raises_for_non_numeric(self):
         self.assertRaises(ValueError, self._callFUT, 'abc')
@@ -153,6 +159,21 @@ class DictOfKeyValuePairsTests(unittest.TestCase):
         expected = {'foo': 'bar,baz', 'baz': 'q,ux'}
         self.assertEqual(actual, expected)
 
+    def test_handles_newlines_inside_quotes(self):
+        actual = datatypes.dict_of_key_value_pairs('foo="a\nb\nc"')
+        expected = {'foo': 'a\nb\nc'}
+        self.assertEqual(actual, expected)
+
+    def test_handles_empty_inside_quotes(self):
+        actual = datatypes.dict_of_key_value_pairs('foo=""')
+        expected = {'foo': ''}
+        self.assertEqual(actual, expected)
+
+    def test_handles_empty_inside_quotes_with_second_unquoted_pair(self):
+        actual = datatypes.dict_of_key_value_pairs('foo="",bar=a')
+        expected = {'foo': '', 'bar': 'a'}
+        self.assertEqual(actual, expected)
+
     def test_handles_unquoted_non_alphanum(self):
         actual = self._callFUT(
             'HOME=/home/auser,FOO=/.foo+(1.2)-_/,'
@@ -223,8 +244,8 @@ class RangeCheckedConversionTests(unittest.TestCase):
     def _getTargetClass(self):
         return datatypes.RangeCheckedConversion
 
-    def _makeOne(self, conversion, rmin=None, rmax=None):
-        return self._getTargetClass()(conversion, rmin, rmax)
+    def _makeOne(self, conversion, min=None, max=None):
+        return self._getTargetClass()(conversion, min, max)
 
     def test_below_lower_bound(self):
         conversion = self._makeOne(lambda *arg: -1, 0)
@@ -294,7 +315,7 @@ class OctalTypeTests(unittest.TestCase):
         try:
             self._callFUT('bad')
             self.fail()
-        except ValueError, e:
+        except ValueError as e:
             expected = 'bad can not be converted to an octal type'
             self.assertEqual(e.args[0], expected)
 
@@ -302,7 +323,7 @@ class OctalTypeTests(unittest.TestCase):
         try:
             self._callFUT('1.2')
             self.fail()
-        except ValueError, e:
+        except ValueError as e:
             expected = '1.2 can not be converted to an octal type'
             self.assertEqual(e.args[0], expected)
 
@@ -315,11 +336,11 @@ class ExistingDirectoryTests(unittest.TestCase):
         self.assertEqual(path, self._callFUT(path))
 
     def test_dir_does_not_exist(self):
-        path = os.path.join(os.path.dirname(__file__), 'nonexistant')
+        path = os.path.join(os.path.dirname(__file__), 'nonexistent')
         try:
             self._callFUT(path)
             self.fail()
-        except ValueError, e:
+        except ValueError as e:
             expected = "%s is not an existing directory" % path
             self.assertEqual(e.args[0], expected)
 
@@ -328,7 +349,7 @@ class ExistingDirectoryTests(unittest.TestCase):
         try:
             self._callFUT(path)
             self.fail()
-        except ValueError, e:
+        except ValueError as e:
             expected = "%s is not an existing directory" % path
             self.assertEqual(e.args[0], expected)
 
@@ -338,13 +359,6 @@ class ExistingDirectoryTests(unittest.TestCase):
             path = self._callFUT('~')
             self.assertEqual(home, path)
 
-    def test_expands_here(self):
-        datatypes.here = os.path.dirname(__file__)
-        try:
-            self.assertEqual(self._callFUT('%(here)s'), datatypes.here)
-        finally:
-            datatypes.here = None
-
 class ExistingDirpathTests(unittest.TestCase):
     def _callFUT(self, arg):
         return datatypes.existing_dirpath(arg)
@@ -356,13 +370,13 @@ class ExistingDirpathTests(unittest.TestCase):
         self.assertEqual(self._callFUT('foo'), 'foo')
 
     def test_raises_if_dir_does_not_exist(self):
-        path = os.path.join(os.path.dirname(__file__), 'nonexistant', 'foo')
+        path = os.path.join(os.path.dirname(__file__), 'nonexistent', 'foo')
         try:
             self._callFUT(path)
             self.fail()
-        except ValueError, e:
+        except ValueError as e:
             expected = ('The directory named as part of the path %s '
-                        'does not exist.' % path)
+                        'does not exist' % path)
             self.assertEqual(e.args[0], expected)
 
     def test_raises_if_exists_but_not_a_dir(self):
@@ -371,9 +385,9 @@ class ExistingDirpathTests(unittest.TestCase):
         try:
             self._callFUT(path)
             self.fail()
-        except ValueError, e:
+        except ValueError as e:
             expected = ('The directory named as part of the path %s '
-                        'does not exist.' % path)
+                        'does not exist' % path)
             self.assertEqual(e.args[0], expected)
 
     def test_expands_home(self):
@@ -382,14 +396,6 @@ class ExistingDirpathTests(unittest.TestCase):
             path = self._callFUT('~/foo')
             self.assertEqual(os.path.join(home, 'foo'), path)
 
-    def test_expands_here(self):
-        datatypes.here = os.path.dirname(__file__)
-        try:
-            expected = os.path.join(datatypes.here, 'foo')
-            self.assertEqual(self._callFUT('%(here)s/foo'), expected)
-        finally:
-            datatypes.here = None
-
 class LoggingLevelTests(unittest.TestCase):
     def _callFUT(self, arg):
         return datatypes.logging_level(arg)
@@ -444,8 +450,7 @@ class InetStreamSocketConfigTests(unittest.TestCase):
     def test_repr(self):
         conf = self._makeOne('127.0.0.1', 8675)
         s = repr(conf)
-        self.assertTrue(s.startswith(
-            '<supervisor.datatypes.InetStreamSocketConfig at'), s)
+        self.assertTrue('supervisor.datatypes.InetStreamSocketConfig' in s)
         self.assertTrue(s.endswith('for tcp://127.0.0.1:8675>'), s)
 
     def test_addr(self):
@@ -502,8 +507,7 @@ class UnixStreamSocketConfigTests(unittest.TestCase):
     def test_repr(self):
         conf = self._makeOne('/tmp/foo.sock')
         s = repr(conf)
-        self.assertTrue(s.startswith(
-            '<supervisor.datatypes.UnixStreamSocketConfig at'), s)
+        self.assertTrue('supervisor.datatypes.UnixStreamSocketConfig' in s)
         self.assertTrue(s.endswith('for unix:///tmp/foo.sock>'), s)
 
     def test_get_addr(self):
@@ -563,7 +567,7 @@ class UnixStreamSocketConfigTests(unittest.TestCase):
         try:
             call_create_and_bind(conf)
             self.fail()
-        except ValueError, e:
+        except ValueError as e:
             expected = "Could not change ownership of socket file: msg"
             self.assertEqual(e.args[0], expected)
             self.assertFalse(os.path.exists(tf_name))
@@ -582,7 +586,7 @@ class UnixStreamSocketConfigTests(unittest.TestCase):
         try:
             call_create_and_bind(conf)
             self.fail()
-        except ValueError, e:
+        except ValueError as e:
             expected = "Could not change permissions of socket file: msg"
             self.assertEqual(e.args[0], expected)
             self.assertFalse(os.path.exists(tf_name))
@@ -633,13 +637,11 @@ class SocketAddressTests(unittest.TestCase):
         return self._getTargetClass()(s)
 
     def test_unix_socket(self):
-        import socket
         addr = self._makeOne('/foo/bar')
         self.assertEqual(addr.family, socket.AF_UNIX)
         self.assertEqual(addr.address, '/foo/bar')
 
     def test_inet_socket(self):
-        import socket
         addr = self._makeOne('localhost:8080')
         self.assertEqual(addr.family, socket.AF_INET)
         self.assertEqual(addr.address, ('localhost', 8080))
@@ -703,16 +705,16 @@ class SignalNumberTests(unittest.TestCase):
         try:
             self._callFUT('12345678')
             self.fail()
-        except ValueError, e:
-            expected = "value 12345678 is not a valid signal number"
+        except ValueError as e:
+            expected = "value '12345678' is not a valid signal number"
             self.assertEqual(e.args[0], expected)
 
     def test_raises_for_bad_name(self):
         try:
             self._callFUT('BADSIG')
             self.fail()
-        except ValueError, e:
-            expected = "value BADSIG is not a valid signal name"
+        except ValueError as e:
+            expected = "value 'BADSIG' is not a valid signal name"
             self.assertEqual(e.args[0], expected)
 
 class AutoRestartTests(unittest.TestCase):
@@ -737,7 +739,7 @@ class AutoRestartTests(unittest.TestCase):
         try:
             self._callFUT('bad')
             self.fail()
-        except ValueError, e:
+        except ValueError as e:
             self.assertEqual(e.args[0], "invalid 'autorestart' value 'bad'")
 
 class ProfileOptionsTests(unittest.TestCase):
